@@ -116,6 +116,8 @@ class CGDB:
         """
         return self._element_contexts_manager.element_contexts()
 
+    def element_context_by_element(self, element_mark: str, aggregation: str, timestamp_code: str, level_code:str = None):
+        return self._element_contexts_manager.element_context_by_element(element_mark, aggregation, timestamp_code, level_code)
     def create_element_context(self, element, aggregation, timeStep, level=None):
         return self._element_contexts_manager.create_element_context(element, aggregation, timeStep, level)
 
